
/*Initial Steps to get the data*/
/* 1. Download GDP Per capita constant 2015 USD from WDI for 2000-2022.
   Source: https://data.worldbank.org/indicator/NY.GDP.PCAP.KD?end=2022&start=2001 */
/* This step involves obtaining GDP per capita data from the World Development Indicators (WDI) database for the years 2000 to 2022. The data is downloaded in constant 2015 US dollars, which allows for meaningful comparisons over time.*/

/* 2. Download most recent WWBI Indicators */
*Source: https://datacatalog.worldbank.org/int/search/dataset/0038132
/* Here, we acquire the latest Worldwide Bureaucracy Indicators (WWBI) dataset, which provides information on various aspects of public sector performance and capacity. The dataset is saved locally for further analysis.*/

/* 3. Download WB regional classifications */
/* Source: https://datahelpdesk.worldbank.org/knowledgebase/articles/906519-world-bank-country-and-lending-groups */
/* This step involves obtaining the World Bank's regional disaggregation data, which classifies countries into different regions based on geographical and income characteristics. This classification is important for regional analysis and comparison.*/

/*NOTE: Figure 3 and Figure 11 are using unpublished calculations from WWBI. They have separate data files. */

clear

	*** Set filepaths
		//Turkan
		if "`c(username)'" == "wb536725" 	{
			global folder 	"C:\Users\wb536725\OneDrive - WBG\Desktop\WWBI\EFI Note_ to be shared"
		}	
		
		//Ayesha
		if "`c(username)'" == "wb581100" 	{
			global folder 	"C:\Users\wb581100\OneDrive - WBG\EFI Note_ to be shared"
		}	
		
		//Replicator
		if "`c(username)'" == "wb614536" 	{
			global folder 	"C:\Temp\RR_WLD_2024_140\Reproducibility package\"
		}

		//Filepaths
		global f_input		"${folder}/Data/input"
		global f_output_data		"${folder}/Data/output/data"
		global f_output_fig		"${folder}/Data/output/figures"
		global f_output_fig_img		"${folder}/Data/output/figures/img"
		
* set ado folder

sysdir set PLUS "$folder/Scripts/ado"

***--------------------------------------------------------------------------***
*STEP 1 


*Editing region classification file
/* Importing the region classification data from an Excel file and preparing it for merging with other datasets. The variables are renamed for clarity and consistency.*/

import excel "${f_input}/CLASS.xlsx", sheet("List of economies") firstrow case(lower) clear
ren economy countryname
ren code countrycode
*Dropping economies that we dont need in the analysis (lending groups, income groups, wolrd average, and other grouppings)
drop in 219/269
save "${f_input}/classification.dta", replace


***--------------------------------------------------------------------------***
*STEP 2

*Editing WWBI File
/* Importing the original WWBI data from an Excel file and preparing it for analysis. The variables are renamed for clarity and consistency.*/
import excel "${f_input}/WWBIEXCEL.xlsx", sheet("Data") firstrow case(lower) clear
/* Creating a new labeled numeric variable for countryname */
/* This step generates a new numeric variable for country names, which facilitates data manipulation and analysis.*/
encode countryname, generate(countryname_num)

/* Creating a new variable for the latest data per country and per indicator until the year of 2010 (y=2020 and o=2010). */
/* Here, we create a new variable 'latest_data' to capture the most recent data available for each country and indicator. The variable is assigned values based on the year of the data.*/
gen latest_data=y
replace latest_data= x if latest_data==.
replace latest_data= w if latest_data==.
replace latest_data= v if latest_data==.
replace latest_data= u if latest_data==.
replace latest_data= t if latest_data==.
replace latest_data= s if latest_data==.
replace latest_data= r if latest_data==.
replace latest_data= q if latest_data==.
replace latest_data= p if latest_data==.
replace latest_data= o if latest_data==.
replace latest_data= n if latest_data==.
replace latest_data= m if latest_data==.
replace latest_data= l if latest_data==.
replace latest_data= k if latest_data==.
replace latest_data= j if latest_data==.
replace latest_data= i if latest_data==.
replace latest_data= h if latest_data==.
replace latest_data= g if latest_data==.
replace latest_data= f if latest_data==.
replace latest_data= e if latest_data==.

*Since we have the latest_data indicator now, dropping the rest.
drop e f g h i j k l m n o p q r s t u v w x y
drop if latest_data==.

*Sorting the data for merging
sort countryname indicatorname

/* Saving the dataset */
/* The dataset is saved after the initial editing and variable creation steps for future use and analysis.*/
save "${f_input}/WWBIdata.dta", replace

***--------------------------------------------------------------------------***
*STEP 3

/*Merging regional classification with WWBI data*/
/* The region classification data is merged with the WWBI dataset based on country names and codes. This allows for regional analysis of the WWBI indicators.*/
merge m:m countryname countrycode using "${f_input}/classification.dta"

/* There are some countries without the regions assigned due to spelling difference */
/* Countries with missing or mismatched region assignments are corrected based on their geographical location.*/
encode region, generate(region_num)
tab region_num
tab region_num, nol
tab countryname_num if _merge==1
tab countryname_num if _merge==1, nol

/* Adding missing countries to regions */
/* Countries that were not initially assigned to regions are manually assigned based on their geographical location.*/
replace region_num=4 if countryname_num==200 | countryname_num==54 | countryname_num==81
replace region_num=2 if countryname_num==146 | countryname_num==185 | countryname_num==46
replace region_num=7 if countryname_num==41 | countryname_num==47 | countryname_num==48 | countryname_num==179 | countryname_num==173
replace region_num=1 if countryname_num==92 | countryname_num==26 | countryname_num==174 | countryname_num==198 | countryname_num==119 | countryname_num==115
replace region_num=3 if countryname_num==178 |  countryname_num==197  |  countryname_num==44

/*Creating a labeled numerical variable for the indicators */
encode indicatorname, generate(indicatorname_num)

/* The merged dataset is saved for further analysis, with the unnecessary merge indicator variable dropped.*/
*drop  indicatorcode lendingcategory f incomegroup
drop if latest_data==.
drop _merge

save "${f_input}/mergedregionwwbi.dta", replace

***--------------------------------------------------------------------------***
*STEP 4
/* Merging GDP Per capita with WWBI data */

* Step 4a: Editing GDP data
* Importing GDP per capita data from an Excel file and preparing it for merging with the WWBI dataset. 
* Only the data for the year 2019 is kept for consistency with the WWBI dataset.
import excel "${f_input}/GDP Per Capita 2015 USD.xls", sheet("Data") firstrow case(lower) clear

* Keeping only the year 2019 before the pandemic to merge with the WWBI. 
* The latest data in WWBI is from 2020.
drop e f g h i j k l m n o p q r s t u v w y z aa ab
ren x gdppercapita2015_2019

* Transforming GDP per capita values to natural logarithms for analysis purposes.
gen lngdp = log10(gdppercapita2015_2019)

* Saving the edited GDP data
save "${f_input}/gdppercapita_2015constant_2019.dta", replace

* Step 4b: Merging GDP per capita with WWBI and regional classification
* The GDP per capita data is merged with the WWBI dataset based on country names. 
* This allows for an analysis of the relationship between GDP per capita and public sector indicators.
use "${f_input}/mergedregionwwbi.dta", clear
merge m:m countryname using "${f_input}/gdppercapita_2015constant_2019.dta"

* Dropping values for those countries that are not in WWBI
drop if _merge == 2

* Cleaning the additional variables we don't need for the analysis
drop f indicatorcode _merge

save "${f_output_data}/finaldata-forfigures.dta", replace


***--------------------------------------------------------------------------***
*STEP 5
/* 	Collapsing the data to get the global averages */

preserve
collapse (mean) latest_data, by ( indicatorname_num)
save "${f_output_data}/global_averages.dta", replace
restore
***--------------------------------------------------------------------------***


***--------------------------------------------------------------------------***
*STEP 6
/* 	Collapsing the data to get the regional averages */

preserve
collapse (mean) latest_data, by ( indicatorname_num region_num)
save "${f_output_data}/regional_averages.dta", replace
restore


***--------------------------------------------------------------------------***\

/*FIGURES FOR THE PAPER */

/*Figure 1: Public sector emp. as od paid emp by healthcare
Note: the numbers below are in proportion, while we converted to percentage in the report*/

	graph hbar (mean) latest_data if indicatorname_num==210, over(region_num) blabel(bar) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Public sector employment, as a share of paid employment, healthcare", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig1.gph", replace
		graph export "${f_output_fig_img}/fig1.png", replace


*Figure 2: The share of the health workforce in public sector employment increases with country income.
 twoway (scatter latest_data lngdp if indicatorname_num==70), ytitle(`"Health workers, as a share of public paid employees"') xtitle(`"Log of gdp per capita constant 2015 usd"') title(`""', size(vsmall))
		graph save  "Graph" "${f_output_fig}/fig2.gph", replace
		graph export "${f_output_fig_img}/fig2.png", replace
		

*Figure 3: Country income and supply of medical workers are positively correlated.
*Figure 3 is using additional data from the WWBI labor force data. Population and GDP per capita data is coming from World Development Indicators (WDI).
*use"${f_input}/fig3_medicalperpopulation.dta", clear
*rename medicalper1000 medpercapita
*rename lngdppc loggdppercapita
* twoway (scatter medpercapita loggdppercapita ), ytitle(`"Medical workers employed per capita"') xtitle(`"Log of gdp per capita constant 2015 usd"') title(`"Country income and supply of medical workers are positively correlated."', size(vsmall))
*		graph save  "Graph" "${f_output_fig}/fig3.gph", replace
*		graph export "${f_output_fig_img}/fig3.png", replace


/*Continuing using the merged data*/
use "${f_output_data}/finaldata-forfigures.dta", clear

/*Figure 4: Public sector healthcare workers are older compared to their private sector counterparts.*/
/*Since data is coded as long, and the values are shown under the same variable, we decided to show each bar in the note as a separate figure here. In the note, they are shown as groupped bars.*/

*Figure 4a below corresponds to "Mean age of private paid employees, by industry: Health"

	graph hbar (mean) latest_data if indicatorname_num==94, over(region_num)  blabel(bar, format(%2.1g))  ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Mean age of private paid employees, by industry: Health", size(small)) ///
		ytitle("Percentage", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig4a.gph", replace
		graph export "${f_output_fig_img}/fig4a.png", replace


*Figure 4b below corresponds to  Mean age of public paid employees, by industry: Health"
	graph hbar (mean) latest_data if indicatorname_num==100, over(region_num)  blabel(bar, format(%2.1g))  ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Mean age of public paid employees, by industry: Health", size(small)) ///
		ytitle("Percentage", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig4b.gph", replace
		graph export "${f_output_fig_img}/fig4b.png", replace
		
		

*Figure 5: Many countries face shortages of skilled healthcare workers.
/*Since data is coded as long, and the values are shown under the same variable, we decided to show each bar in the note as a separate figure here. In the note, they are shown as groupped bars.*/

* a) Figure 5a below corresponds to "Individuals with tertiary education as a share of public paid employees, health"

	graph hbar (mean) latest_data if indicatorname_num==90, over(region_num)  blabel(bar, format(%2.1g))  ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Individuals with tertiary education as a share of public paid employees", size(small)) ///
		ytitle("Percentage", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig5a.gph", replace
		graph export "${f_output_fig_img}/fig5a.png", replace


* b) Figure 5b below corresponds to "Individuals with tertiary education as a share of private paid employees, health"
	
	graph hbar (mean) latest_data if indicatorname_num==87, over(region_num)  blabel(bar, format(%2.1g))  ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Individuals with tertiary education as a share of private paid employees", size(small)) ///
		ytitle("Percentage", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig5b.gph", replace
		graph export "${f_output_fig_img}/fig5b.png", replace


*Figure 6:  Globally, most public healthcare workers are women.

	graph hbar (mean) latest_data if indicatorname_num==43, over(region_num) blabel(bar) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Females, as a share of public healthcare workforce", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig6.gph", replace
		graph export "${f_output_fig_img}/fig6.png", replace


*Figure 7: Women are only 36 percent of all managers in the public sector
*Since data is coded as long, and the values are shown under the same variable, we decided to show each bar in the note as a separate figure here. In the note, they are shown as groupped bars.
* Figures below corresponds to the occupations in the public sector.

	graph hbar (mean) latest_data if indicatorname_num==49, blabel(bar) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Females, as a share of public paid employees by occupational group:clerks", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig7_pub_clerks.gph", replace
		graph export "${f_output_fig_img}/fig7_pub_clerks.png", replace
		
	graph hbar (mean) latest_data if indicatorname_num==50, blabel(bar) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Females, as a share of public paid employees by occupational group:elementary", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig7_pub_elementary.gph", replace
		graph export "${f_output_fig_img}/fig7_pub_elementary.png", replace

	graph hbar (mean) latest_data if indicatorname_num==51, blabel(bar) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Females, as a share of public paid employees by occupational group:managers", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig7_pub_managers.gph", replace
		graph export "${f_output_fig_img}/fig7_pub_managers.png", replace

	graph hbar (mean) latest_data if indicatorname_num==52, blabel(bar) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Females, as a share of publicpaid employees by occupational group:profesionals", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig7_pub_profesionals.gph", replace
		graph export "${f_output_fig_img}/fig7_pub_profesionals.png", replace

 	graph hbar (mean) latest_data if indicatorname_num==53, blabel(bar) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Females, as a share of public paid employees by occupational group:technicians", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig7_pub_technicians.gph", replace
		graph export "${f_output_fig_img}/fig7_pub_technicians.png", replace

* Figures below corresponds to the occupations in the private sector.
		
	graph hbar (mean) latest_data if indicatorname_num==30, blabel(bar) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Females, as a share of private paid employees by occupational group:clerks", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig7_priv_clerks.gph", replace
		graph export "${f_output_fig_img}/fig7_priv_clerks.png", replace
		
	graph hbar (mean) latest_data if indicatorname_num==31, blabel(bar) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Females, as a share of private paid employees by occupational group:elementary", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig7_priv_elementary.gph", replace
		graph export "${f_output_fig_img}/fig7_priv_elementary.png", replace

	graph hbar (mean) latest_data if indicatorname_num==32, blabel(bar) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Females, as a share of private paid employees by occupational group:managers", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig7_priv_managers.gph", replace
		graph export "${f_output_fig_img}/fig7_priv_managers.png", replace

	graph hbar (mean) latest_data if indicatorname_num==33, blabel(bar) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Females, as a share of private paid employees by occupational group:profesionals", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig7_priv_profesionals.gph", replace
		graph export "${f_output_fig_img}/fig7_priv_profesionals.png", replace

 	graph hbar (mean) latest_data if indicatorname_num==34, blabel(bar) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Females, as a share of private paid employees by occupational group:technicians", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig7_priv_technicians.gph", replace
		graph export "${f_output_fig_img}/fig7_priv_technicians.png", replace


*Figure 8: Public sector health workers receive a wage premium
*Since data is coded as long, and the values are shown under the same variable, we decided to show each bar in the note as a separate figure here. In the note, they are shown as groupped bars.

* Figure 8a below corresponds to "Public sector wage premium, by industry: Health (compared to all private employees)"
	graph hbar (mean) latest_data if indicatorname_num==259,  blabel(bar) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Public sector wage premium, by industry: Health (compared to all private employees)", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig8a.gph", replace
		graph export "${f_output_fig_img}/fig8a.png", replace


		
*  Figure 8b below corresponds to "Public sector wage premium, by industry: Health (compared to formal wage employees)"
	graph hbar (mean) latest_data if indicatorname_num==260,  blabel(bar) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Public sector wage premium, by industry: Health (compared to formal wage employees)", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig8b.gph", replace
		graph export "${f_output_fig_img}/fig8b.png", replace


*Figure 9: The size of the public sector wage premium varies significantly across countries.

 twoway (scatter latest_data lngdp if indicatorname_num==262), ytitle(`"Public sector wage premium: Medical workers (compared to formal wage employees)"') xtitle(`"Log of gdp per capita constant 2015 usd"') title(`""', size(vsmall))
		graph save  "Graph" "${f_output_fig}/fig9.gph", replace
		graph export "${f_output_fig_img}/fig9.png", replace
		

*In the note, figure 10 has two components.

*Figure 10a: Wages of hospital doctors and nurses relative to the global median by region
	graph hbar (mean) latest_data if indicatorname_num==7, over(region_num) blabel(bar, format(%2.1g)) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Cross-country public sector pay comparison ratio, Hospital doctor", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig10a.gph", replace
		graph export "${f_output_fig_img}/fig10a.png", replace

*Figure 10b:Cross-country public sector pay comparison ratio, by occupation: Hospital nurse (using median)

	graph hbar (mean) latest_data if indicatorname_num==9, over(region_num) blabel(bar, format(%2.1g)) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Cross-country public sector pay comparison ratio, Hospital nurse", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig10b.gph", replace
		graph export "${f_output_fig_img}/fig10b.png", replace


*Figure 11: Public sector health workers are paid less compared to public administration workers in countries we have data on.

*use "${f_input}/fig11_wagepremium.dta", clear

 *twoway (scatter health logofgdppercapita  ), ytitle(`"Public sector wage premium for health workers ( compared to public administration workers)"') xtitle(`"Log of gdp per capita constant 2015 usd"') title(`" Public sector health workers are paid less compared to public administration workers."', size(vsmall))
	*	graph save  "Graph" "${f_output_fig}/fig11.gph", replace
	*	graph export "${f_output_fig_img}/fig11.png", replace



*Figure 12 : In most regions, women tend to earn a higher wage when employed in the public sector healthcare as opposed to the private sector.
*Since data is coded as long, and the values are shown under the same variable, we decided to show each bar in the note as a separate figure here. In the note, they are shown as groupped bars.

/*Continuing using the merged data*/
use "${f_output_data}/finaldata-forfigures.dta", clear

*Figure 12a below corresponds to "Public sector wage premium for females, by industry: Health (compared to paid wage employees)"
	graph hbar (mean) latest_data if indicatorname_num==244, over(region_num) blabel(bar) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Public sector wage premium for females, by industry: Health (compared to paid wage employees)", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig12a.gph", replace
		graph export "${f_output_fig_img}/fig12a.png", replace

*Figure 12b below corresponds to "Public sector wage premium for females, by occupation: Medical workers (compared to paid wage employees)"
	graph hbar (mean) latest_data if indicatorname_num==245, over(region_num) blabel(bar) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Public sector wage premium for females, by occupation: Medical workers (compared to paid wage employees)", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig12b.gph", replace
		graph export "${f_output_fig_img}/fig12b.png", replace
		
		
*Figure 13: Female health workers receive a wage penalty compared to their male counterparts.
	graph hbar (mean) latest_data if indicatorname_num==65, over(region_num) blabel(bar) ///
		aspectratio(0.75) ///  
		xsize(2) ysize(1) ///
		scheme(plotplain)   ///
		title("Gender wage gap in the public sector, by industry: Health (compared to male paid employees)", size(small)) ///
		ytitle("Mean", size(small)) ///
		graphregion(color(white)) ///
		legend( position(6) row(2) size(small) symxsize(6)) 
		graph save  "Graph" "${f_output_fig}/fig13.gph", replace
		graph export "${f_output_fig_img}/fig13.png", replace
		











